package com.showmejava.jtoh;

//////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2000, Eric M. Burke (ericb@showmejava.com)
// All rights reserved.
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions are met:
//
// - Redistributions of source code must retain the above copyright notice,
//   this list of conditions and the following disclaimer.
// 
// - Redistributions in binary form must reproduce the above copyright notice,
//   this list of conditions and the following disclaimer in the documentation
//   and/or other materials provided with the distribution.
// 
// - Neither name of the ShowMeJava.com nor the names of its contributors may 
//   be used to endorse or promote products derived from this software without
//   specific prior written permission. 
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
// TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE. 
/////////////////////////////////////////////////////////////////////////////

import java.io.*;

/**
 * Recognizes single line comments.
 *
 * @author Eric M. Burke
 * @version $Id: SingleLineCommentState.java,v 1.2 2000/04/01 05:20:13 ericb Exp $
 */
public class SingleLineCommentState extends State {
    
    public SingleLineCommentState(char[] characters) {
        super(characters);
    }
    
    /**
     * @param startPos the position to check in the file.
     * @return true if the specified position is the beginning
     * of this state.
     */
    public boolean isStartPos(int startPos) {
        char curChar = getCharAt(startPos);
        char nextChar = getCharAt(startPos+1);
        if (curChar == '/' && nextChar == '/') {
            return true;
        }
        return false;
    }
    
    
    
    protected void writeBeginTag(PrintWriter pw) {
        pw.print("<font class=\"singleLineComment\">");
    }
    
    protected void writeEndTag(PrintWriter pw) {
        pw.print("</font>");
    }
    
    
    /**
     * @param startPos the starting position of this state.
     * @return the end position, or JavaFile.EOF for end of file.
     */
    protected int findEndPos(int startPos) {
        int length = getLength();
        int endPos = startPos+2;//
        while (endPos<length) {
            char curChar = getCharAt(endPos);
            if (curChar == 10 || curChar == 13) {
                return endPos;
            }
            endPos++;
        }
        return endPos;
    }
}
